
clear all
close all

% fpathrol = '..\runs\V4R14\Roller\';
% fpath    = '..\runs\V4R14\NoRoller\';

fpathrol = '..\runs\V4B15\Roller\';
fpath    = '..\runs\V4B15\NoRoller\';

%measured
Hsm = load('..\data\kuriyama_wave_height.txt');
um = load('..\data\kuriyama_longshore_current.txt');
hm = load('..\data\kuriyama_depth.txt');
xs = 400;

%Grid
filename = [fpath,'Flow_kuriyama_grid.h5'];
info = hdf5info(filename);
s = info.GroupHierarchy.Groups;
nx = s.Attributes(7).Value;
ny = s.Attributes(8).Value;
origin = s.Attributes(6).Value;
x = hdf5read(s.Datasets(1));
y = hdf5read(s.Datasets(2));
x = - x - origin(1) + xs;
depth = hdf5read(s.Groups(1).Groups(2).Datasets(4));
depth = reshape(depth,[nx,ny])';

%calculated
filename = [fpath,'Flow_kuriyama_sol.h5'];
sol = readcmsh5(filename);
ind = 75;
%V-velocity
v = reshape(sol.Current_Velocity.Values(2,:,end),[nx,ny])';
v(abs(v)>10) = NaN;
%Wave height
Hs = reshape(sol.Wave_Height.Values(:,end),[nx,ny]);
Hs(Hs<0) = NaN;

filename = [fpathrol,'Flow_kuriyama_sol.h5'];
solrol = readcmsh5(filename);
%V-velocity
vr = reshape(solrol.Current_Velocity.Values(2,:,end),[nx,ny])';
vr(abs(vr)>10) = NaN;
%Wave height
Hsr = reshape(solrol.Wave_Height.Values(:,end),[nx,ny]);
Hsr(Hsr<0) = NaN;

%Depth
depth2 = -depth(ind,:)';
%Transect
Hs2 = Hs(:,ind);
v2 = v(ind,:);
Hsr2 = Hsr(:,ind);
vr2 = vr(ind,:);

%Statistics
rmse = zeros(4,1);
nrmse = zeros(4,1);
nmae = zeros(4,1);
R2 = zeros(4,1);
B = zeros(4,1);

%Wave height
yc=interp1(x,Hs2,Hsm(:,1));
ym=Hsm(:,2);
rmse(1) = sqrt(mean((yc-ym).^2));
nrmse(1) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
nmae(1) = mean(abs((yc-ym)))/(max(ym)-min(ym));
R = corrcoef(yc,ym);
R2(1) = R(1,2).^2;
B(1) = mean(yc-ym);

yc=interp1(x,Hsr2,Hsm(:,1));
ym=Hsm(:,2);
rmse(2) = sqrt(mean((yc-ym).^2));
nrmse(2) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
nmae(2) = mean(abs(yc-ym))/(max(ym)-min(ym));
R = corrcoef(yc,ym);
R2(2) = R(1,2).^2;
B(2) = mean(yc-ym);

%Longshore current
yc=interp1(x,v2,um(:,1));
ym=um(:,2);
rmse(3) = sqrt(mean((yc-ym).^2));
nrmse(3) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
nmae(3) = mean(abs(yc-ym))/(max(ym)-min(ym));
R = corrcoef(yc,ym);
R2(3) = R(1,2).^2;
B(3) = mean(yc-ym);

yc=interp1(x,vr2,um(:,1));
ym=um(:,2);
rmse(4) = sqrt(mean((yc-ym).^2));
nrmse(4) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
nmae(4) = mean(abs(yc-ym))/(max(ym)-min(ym));
R = corrcoef(yc,ym);
R2(4) = R(1,2).^2;
B(4) = mean(yc - ym);

% figure, plot(yc,ym,'.'), axis equal

disp('--- LSTF Case 1 Goodness of Fit Statistics ---')
disp('Transect    Hs      Hsr      V      Vr')
fprintf(1,'NRMSE    %7.4f,%7.4f,%7.4f,%7.4f\n',nrmse);
fprintf(1,'NMAE    %7.4f,%7.4f,%7.4f,%7.4f\n',nmae);
fprintf(1,'R^2     %7.3f,%7.3f,%7.4f,%7.4f\n',R2);
fprintf(1,'Bias    %7.3f,%7.3f,%7.4f,%7.4f\n',B);

%---- Plotting --------------
be=6;
%Wave height
wh=2.4;
figure('position',[361   276   560   279])
%[ax,h1,h2] = plotyy(x,Hs2,x,depth2);
[ax,h1,h2] = plotyy(x,Hs2,hm(:,1),hm(:,2));
set(h1,'color','r','linewidth',2,'linestyle',':')
set(h2,'color','k','linewidth',2,'linestyle','--')
set(ax(1),'xlim',[0,400],'ylim',wh*[-1 1],'YColor','k')
set(ax(2),'xlim',[0,400],'ylim',be*[-1 1],'ydir','normal','YColor','k')
set(ax(1),'ytick',linspace(-wh,wh,7),'position',[0.13 0.14 0.775 0.75])
set(ax(2),'ytick',linspace(-be,be,7),'position',[0.13 0.14 0.775 0.75])
set(ax,'nextplot','add')
plot(ax(1),Hsm(:,1),Hsm(:,2),'ok','Markerfacecolor','k')
% plot(ax(2),x,depth2,'o')
plot(ax(1),x,Hsr2,'b-','linewidth',2)
xlabel('Distance, m')
ylabel(ax(1),'Significant Wave Height, m')
ylabel(ax(2),'Bed Elevation, m SWL')
%title('Kuriyama and Ozaki')
legend('No Roller','Measured','Roller','Bed Elevation',0)
set(gcf,'PaperPositionMode','auto')
% saveas(gcf,'..\images\Kuriyama_Ozaki_WavePro.png') 

% return
%Longshore current
cv = 0.9;
figure('position',[361   276   560   279])
% [ax,h1,h2] = plotyy(x,v2,x,depth2);
[ax,h1,h2] = plotyy(x,v2,hm(:,1),hm(:,2));
set(h1,'color','r','linewidth',2,'linestyle',':')
set(h2,'color','k','linewidth',2,'linestyle','--')
set(ax(1),'xlim',[0,400],'ylim',cv*[-1 1],'YColor','k')
set(ax(2),'xlim',[0,400],'ylim',be*[-1 1],'ydir','normal','YColor','k')
set(ax(1),'ytick',linspace(-cv,cv,7),'position',[0.13 0.14 0.775 0.75])
set(ax(2),'ytick',linspace(-be,be,7),'position',[0.13 0.14 0.775 0.75])
set(ax,'nextplot','add')
plot(ax(1),x,vr2,'b-','linewidth',2)
plot(ax(1),um(:,1),um(:,2),'ok','Markerfacecolor','k')
% plot(ax(2),x,depth2,'o')
xlabel('Distance, m')
ylabel(ax(1),'Longshore Current, m/s')
ylabel(ax(2),'Bed Elevation, m SWL')
% title('Kuriyama')
legend('Bed Elevation','No Roller','Roller','Measured',0)
set(gcf,'PaperPositionMode','auto')
% saveas(gcf,'..\images\Kuriyama_Ozaki_CurrentPro.png') 
% 
return



